@@ -94,6 +94,12 @@ setup <- function (data,
   
   ts_list <- setupDataLists(data = data, ctrlOpts = ctrlOpts, lv_model = lv_model)
   
+  # Warning for plot when Variables = 3
+  if(plot == TRUE && (length(ts_list[[1]][1,]) < 4)){
+    writeLines("gimme WARNING: plot=TRUE changed to plot=FALSE.",
+               " Errors in plotting occur with fewer than 4 nodes.")
+    plot = FALSE
+  }
   
   #-------------------------------------------------------------#
   # lv_gimme
@@ -433,6 +439,7 @@ setup <- function (data,
                 names = c(names(ts_list)), 
                 stringsAsFactors = FALSE
               ),
+              "chisq_cutoff_mi_epc" = qchisq(1-(.05/((length(varLabels$coln)*(length(varLabels$coln)-1)/2)*length(ts_list))), 1),
               "varLabels" = varLabels,
               "ctrlOpts"  = ctrlOpts,
               "lvgimme"   = lvgimme,
